@@ -60,8 +60,8 @@ See F<LICENSE>.
 
 =cut
 
-$^V eq 5.40.2 
-    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.2) ".
+$^V eq 5.42.0 
+    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                    "that PAR::Packer was built with; please rebuild PAR::Packer", 
                    $^X, $^V);
 
@@ -82,7 +82,7 @@ M````````4.5T9`0`````F0````````"9`````````)D````````,`0``````
 M``P!````````!`````````!1Y71D!@``````````````````````````````
 M```````````````````````````0`````````%+E=&0$````</L```````!P
 M^P$``````'#[`0``````D`0```````"0!`````````$`````````!````!0`
-M```#````1TY5`&QO0NR\]3Y]?589&2E@32X?N934+VQI8B]L9"UL:6YU>"UA
+M```#````1TY5`),WFA&'-HBAN-'7LV=^HFY@L/XA+VQI8B]L9"UL:6YU>"UA
 M87)C:#8T+G-O+C$``#L```!)````!`````@````A$!``!<`$A"@"$`6`AD"$
 M@HD`!@D@!(B(@!!!N@`""`````!)````2P```$P```````````````````!.
 M`````````$\```!0````40``````````````4@```%,`````````````````
@@ -174,7 +174,7 @@ M7VEN:70`7U]E;F1?7P!?7V)S<U]E;F1?7P!?7V)S<U]S=&%R=`!S:&%?:6YI
 M=`!?96YD`'!A<E]M:W1M<&1I<@!?961A=&$`<&%R7W-E='5P7VQI8G!A=&@`
 M<&%R7V9I;F1P<F]G`&UY7W!A<E]P;`!P87)?9&EE`'!A<E]I;FET7V5N=@!'
 M3$E"0U\R+C$W`$=,24)#7S(N,S0`1TQ)0D-?,BXS,P`O=7-R+VQI8B]P97)L
-M-2\U+C0P+V-O<F5?<&5R;"]#3U)%``````````$``@`!``$``@`"``(``0`!
+M-2\U+C0R+V-O<F5?<&5R;"]#3U)%``````````$``@`!``$``@`"``(``0`!
 M``(``@`"``$``P`!``(``0`"``(``@`"``(``0`!``$``@`"``0``@`"``(`
 M`0`!``$``0`"``$``0`"``(``@`"``(``0`"``(``0`"``$`!``"``(``@`"
 M``$``@`!``(``@`!``(``0`!``4``@`"``(``@`"``(``0`!``$``0`!``$`
@@ -307,18 +307,18 @@ MD?-3`:GU6P*I_V,MR_\#`OGT`P"JX@``L$(D1_GU`P&JX9,`D4``0/G@5PCY
 M``"`T@```/``8!^1KOW_E_,#`*KB``"P0LA'^>`#%*KA!8!20``_UF`"`+3A
 M`Q2J````\`"@'Y&+_O^7X`,4JN$``+`A)$?YXU=(^2(`0/EC``+K`@"`T@$2
 M`%0-%H+2_V,MB_-30:GU6T*I_7O&J,`#7];@``"P`,!'^?=S"/GW``"P]PI'
-M^?AW"/G[@PCYX0,`JOR'"/G@`Q6JX0\`^18``/`@`#_6P>(?D>`"/];\`P"J
-M@`X`M.```+``7$?Y^*,"D?L``+![\T?YX`<`^?4``+"U[D?Y^7L(^>```+``
-MM$?YX`L`^?I_"/F``T`YP`<`--,``+3B"T#YX0,<JN`#$ZI``#_6@`4`-.`#
-M'*J@`C_6`@0`T?D#%:J"`P*+^@,`JI\#`NNC``!4"@``%%_T'SB?`P+K@```
-M5$``0#D?O`!Q8/__5.`#'*J@`C_6^@,`JN`#%*H@`S_6```:BP`$`)$?_#_Q
-M*`,`5`(`@M)!`(!2Y`,<JN8#%*K@`QBJ!0``\`,``/"E`""18R`@D6`#/];B
-M!T#YX:,`D>`#&*I``#_6H```->`[0+D`#!02'R!`<4`#`%3!XA^1``"`TN`"
-M/];\`P"J(/G_M?=S2/GX=TCY^7M(^?I_2/G[@TCY_(=(^9+__Q<S!`"T8`)`
-M.1^X`''@``!4!```\#H`@-+Y``"P.>]'^9Q`'Y'2__\78`9`.2#]_S3X__\7
-MX@``L$)@1_G@`QBJ(0"`4D``/]9`_/\UX0,8J@```/``H!^1"?[_E^$/0/G@
-M`QBJ(``_UO=S2/GX=TCY^7M(^?I_2/G[@TCY_(=(^7;__Q<$``#P.@"`TOD`
-M`+`Y[T?YG$`?D;7__Q?W<TCY^'=(^?N#2/G\ATCY9O__%^```+``F$?Y]W,(
+M^?AW"/G[@PCYX0,`JOR'"/G@`Q6JX0\`^18``/`@`#_6P>(?D>`"/];[`P"J
+M@`X`M.```+``\$?Y^7L(^?4``+"U[D?YX`<`^?D``+`YMT?Y^G\(^>```+``
+M7$?Y^J,"D>`+`/E@`T`Y0`4`-+,``+3A`QNJX`,3JB`#/]8@`P`TX`,;JJ`"
+M/]8"!`#1^`,5JF(#`HO\`P"J?P,"ZZ,``%0*```47_0?.'\#`NN```!40`!`
+M.1^\`'%@__]4X`,;JJ`"/];\`P"JX`,4J@`#/]8``!R+``@`D1_\/_%)`P!4
+MP>(?D0``@-+@`C_6^P,`JJ#[_[7W<TCY^'=(^?E[2/GZ?TCY^X-(^?R'2/FF
+M__\7LP8`M&`"0#D?N`!QX```5`$``/`\`(#2^```L!CO1_D[0!^1Y?__%V`&
+M0#D@_?\T^/__%^<'0/D"`(+200"`4N0#&ZKF`Q2JX`,:J@4``/`#``#PI0`@
+MD6,@()'@`#_6X@M`^>&C`)'@`QJJ0``_U@#[_S7@.T"Y``P4$A\@0'&!^O]4
+MX@``L$)@1_G@`QJJ(0"`4D``/];`^?\UX0,:J@```/``H!^1"?[_E^$/0/G@
+M`QJJ(``_UO=S2/GX=TCY^7M(^?I_2/G[@TCY_(=(^7;__Q<!``#P/`"`TO@`
+M`+`8[T?Y.T`?D;3__Q?W<TCY^'=(^?N#2/G\ATCY9O__%^```+``F$?Y]W,(
 M^?AW"/GY>PCY^G\(^?N#"/G\APCY```_UA\@`]4?(`/5_7N^J>$%@%+B``"P
 M0CQ'^?T#`)'S"P#Y\P,`JD``/]8?``#Q8`:`FO,+0/G]>\*H\```L!#"1_D`
 M`A_6'R`#U?U[O:D-`H+2_0,`D?]C+<O_`P+YX0``L"$D1_DB`$#YX@<(^0(`
@@ -582,7 +582,7 @@ M8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD
 M(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````
 M+G!A<@````!S:&]R="!R96%D````````)7,E<V-A8VAE+25S)7,``"5S)7-T
 M96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S```````````8`````````'!E
-M<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V,P``
+M<FP`````,`````````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V-```
 M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@
 M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
 M;&5D("AE<G)N;STE:2D*```````````M90```````"TM````````55-%4@``
@@ -959,8 +959,8 @@ M`Y4"E@%I"@XP0][=U=;3U`X`00L`(````/0!``!@B___>`````!!#B"=!)X#
 M19,"E`%/WMW3U`X`$````!@"``"TB___-``````````P````+`(``."+__\<
 M`0```$$.,)T&G@5%#M!`DP24`Y4"E@%Y"@XP1-[=U=;3U`X`00L`$````&`"
 M``#,C/__!`````````!\````=`(``+R,___T`@```$$.8)T,G@M%#I`BDPJ4
-M"94(E@=A"@Y@0][=U=;3U`X`00M#EP9#F`5!FP)"G`%1F01$F@-Y"M=!V$'9
-M0=I!VT'<00M;"M=!V$'90=I!VT'<00M&V=I!UT'80=M!W$27!D&8!4&9!$&:
+M"94(E@=A"@Y@0][=U=;3U`X`00M#EP9#F`5!FP)"G`%+F01&F@-I"M=!V$'9
+M0=I!VT'<00MO"M=!V$'90=I!VT'<00M&V=I!UT'80=M!W$27!D&8!4&9!$&:
 M`T&;`D&<`2````#T`@``.(___SP`````00X@G02>`T63`D;>W=,.`````&@`
 M```8`P``5(___[P!````00XPG0:>!4,.P"!(E0)&DP1!E`-JTT+40=5!#C!!
 MWMT.`$$.P""5`IT&G@5!U4T.,$'>W0X`00[`(),$E`.5`IT&G@5,"M-"U$+5
